@@ -4,7 +4,7 @@
 *  License, version 2 or above; see the file COPYING for more         *
 *  information.                                                       *
 *                                                                     *
-*  $Id: play.c,v 1.38 2000/11/02 03:48:14 hartmann Exp $
+*  $Id: play.c,v 1.41 2002/12/19 07:04:05 hartmann Exp $
 *                                                                     *
 **********************************************************************/
 
@@ -19,6 +19,7 @@ int GetInput(GameStats* Game)
 	int Multiplier=1;
 	int UserInput=0;
 	char *pathname = NULL;
+	GameStats* LoadedGame;
 
 #ifdef SWEEP_MOUSE
 	MEVENT MouseInput;
@@ -185,7 +186,31 @@ int GetInput(GameStats* Game)
 				SweepError("Can only save game once.");
 				Multiplier=1;
 			}
-			FSGUI();
+			if ( (pathname = FSGUI() ) != NULL )
+			{
+				if ((  LoadedGame = LoadGame(pathname) ) == NULL )
+				{
+					SweepError("Error loading game %s", pathname);
+				}
+				else
+				{
+					werase(Game->Board);
+					wnoutrefresh(Game->Board);
+					werase(Game->Border);
+					wnoutrefresh(Game->Border);
+					delwin(Game->Board);
+					delwin(Game->Border);
+					free(Game->Field);
+					free(Game);
+					Game = LoadedGame;
+					SweepError("Done Loading");
+				}
+				break;
+			}
+			else
+			{
+				SweepError("Unable to open file");
+			}
 		break;
 
 		/* The accepted keys to expose a space. */
@@ -318,6 +343,14 @@ int GetInput(GameStats* Game)
 			SweepMessage("_________0_________0(%u, %u)_________0_________0", Game->CursorX, Game->CursorY);
 			break;
 
+		case 'e':
+			FindNearest(Game);
+			break;
+
+		case 'y':
+			FindNearestBad(Game);
+			break;
+
 		/* The accepted values to suspend the game. */
 		case KEY_SUSPEND:
 		case 'z':
@@ -418,7 +451,7 @@ int GetInput(GameStats* Game)
 #endif /* DEBUG_LOG */
 
 		/* XXX Save a game */
-		case 'p':
+		case 's':
 			SaveGame(Game, "./foo.svg");
 			SweepError("Done Saving");
 			break;
@@ -437,6 +470,17 @@ int GetInput(GameStats* Game)
 			SweepError("Done Loading");
 			break;
 
+		case 'u':
+			if ( Game->Color == 0 )
+			{
+				Game->Color = 1;
+			}
+			else
+			{
+				Game->Color = 0;
+			}
+			break;
+
 		case 'i':
 			SaveGameImage(Game, "foo.ppm");
 			break;
