@@ -1,5 +1,5 @@
 /*********************************************************************
-* $Id: sweep.h.in,v 1.33 2000/11/02 03:47:25 hartmann Exp $
+* $Id: sweep.h.in,v 1.36 2002/12/21 21:32:09 hartmann Exp $
 *********************************************************************/
 
 #ifndef __SWEEP_H__
@@ -35,11 +35,10 @@
 #include <assert.h>
 #include <math.h>
 #include <stdarg.h>
-#include <stdlib.h>
 #include <signal.h>
 
 #ifdef HAVE_LIBNCURSES
-#include "/usr/include/curses.h"
+#include "/ncurses.h"
 #define DEFAULT_LINEDRAW 1
 #else /* HAVE_LIBNCURSES */
 #include <curses.h>
@@ -71,7 +70,7 @@
 /* These are all the defines used in freesweep */
 /* These are defines for convenience */
 #define DELIMITERS " \t="
-#define DFL_GROUP_PATH "no"
+#define DFL_GROUP_PATH ""
 #define MAGIC_NUMBER 128
 
 #ifdef __CYGWIN__
@@ -91,8 +90,8 @@
 
 /* These are defines for maximum accepted values */
 #define MAX_LINE 1024
-#define MAX_H 1024
-#define MAX_W 1024
+#define MAX_H 2048
+#define MAX_W 2048
 #define L_MAX_H 4
 #define L_MAX_W 4
 #define INFO_W 21
@@ -146,6 +145,10 @@
 #define mvgetnstr(y, x, str, n) (wmove(stdscr, y, x)==ERR?ERR:wgetnstr(stdscr, str, n));
 #endif /* mvgetnstr */
 
+#ifndef ValidCoordinate
+#define ValidCoordinate(x,y) ( ( (x>=0) && (x<Game->Width) && (y>=0) && (y<Game->Height) )  ? 1 : 0 )
+#endif
+
 /* These are all the structs used in freesweep */
 /* This is the struct containing all the various drawing characters. */
 typedef struct _DrawChars
@@ -301,6 +304,7 @@ void ClearError();
 int RedrawErrorWin();
 void SweepAlert();
 void SweepMessage(char* format, ...);
+void ChangeSweepAlert(int NewAlert);
 
 /* These are the functions defined in stats.c */
 void PrintStats(GameStats *Game);
@@ -309,7 +313,6 @@ int RedrawStatsWin(void);
 
 /* These are the functions described in utils.c */
 void* xmalloc(size_t num);
-FILE* xfopen(char *name, char *type);
 char* xgetcwd(char *buf, size_t size);
 DIR* xopendir(const char *buf);
 void StartTimer(void);
@@ -327,6 +330,8 @@ void InsertMark(struct Mark **ht, int x, int y);
 char DeleteRandomMark(struct Mark **ht, int *x, int *y);
 void Clear(GameStats *Game);
 void SuperClear(GameStats *Game);
+int FindNearest(GameStats *Game);
+int FindNearestBad(GameStats *Game);
 
 /* These are the functions in fgui.c */
 char* FSGUI(void);
